Class Hierarchy
Date: 2017-11-20

# Hierarchy For All Packages

Package Hierarchies:

- jep

## Class Hierarchy

- java.lang.Object
  - jep.ClassList (implements jep.ClassEnquirer)
  - jep.DirectNDArray<T>
  - jep.InvocationHandler (implements java.lang.reflect.InvocationHandler)
  - jep.Jep (implements java.io.Closeable)
  - jep.JepConfig
  - jep.JepScriptEngine (implements java.lang.AutoCloseable, javax.script.ScriptEngine)
  - jep.JepScriptEngineFactory (implements javax.script.ScriptEngineFactory)
  - jep.NamingConventionClassEnquirer (implements jep.ClassEnquirer)
  - jep.NDArray<T>
  - java.lang.reflect.Proxy (implements java.io.Serializable)
    - jep.Proxy
  - jep.PyConfig
  - jep.Run
  - java.lang.Throwable (implements java.io.Serializable)
    - java.lang.Exception
      - jep.JepException
  - jep.Util

## Interface Hierarchy

- jep.ClassEnquirer